@@ -13,7 +13,7 @@ class Consumer(Model):
     def set_percent(self):
         p_kw = self.inputs.p_set_kw
         if p_kw is None:
-            p_kw = self.state.p_kw
+            return None
 
         p_kw /= self.config.pn_max_kw - self.config.pn_min_kw
 
